@@ -31,9 +31,10 @@ use warnings;
 use vars qw($VERSION);
 
 use Carp qw(croak);
+use Cwd 'abs_path';
 use IO::File;
 
-$VERSION = '1.405';
+$VERSION = '1.406';
 
 sub version()
 {
@@ -42,13 +43,13 @@ sub version()
 
 my @fstab_keys = qw(account boot check dev mount nodename size type vfs vol log);
 my %special_fs = (
-                   swap   => 1,
-                   procfs => 1,
-                   proc   => 1,
-                   tmpfs  => 1,
-                   mntfs  => 1,
-                   autofs => 1,
-                 );
+    swap   => 1,
+    procfs => 1,
+    proc   => 1,
+    tmpfs  => 1,
+    mntfs  => 1,
+    autofs => 1,
+);
 
 # see AIX commands at
 # http://publib.boulder.ibm.com/infocenter/pseries/v5r3/topic/com.ibm.aix.doc/doc/base/alphabeticallistofcommands.htm
@@ -82,6 +83,7 @@ sub new
         my ( $device, $vfs, $nodename, $type, $size, $options, $mount, $account ) =
           @{ $fs_info{$current_filesystem} };
 
+        $args{canondev} and -l $device and $device = abs_path($device);
         $self->{$current_filesystem}->{dev}      = $device;
         $self->{$current_filesystem}->{vfs}      = $vfs;
         $self->{$current_filesystem}->{options}  = $options;
@@ -117,6 +119,7 @@ sub new
 
         my ( $lvname, $type, $lps, $pps, $pvs, $lvstate ) = @{ $fs_info{$current_filesystem} };
 
+        $args{canondev} and -l $lvname and $lvname = abs_path($lvname);
         $self->{$current_filesystem}->{dev}     = $lvname;
         $self->{$current_filesystem}->{vfs}     = $type;
         $self->{$current_filesystem}->{LPs}     = $lps;
@@ -139,7 +142,6 @@ sub new
         my $current_filesystem = '*UNDEFINED*';
         while (<$fstab>)
         {
-
             # skip comments and blank lines.
             next if m{^ [*] }x || m{^ \s* $}x;
 
@@ -159,15 +161,15 @@ sub new
             }
             elsif ( my ( $key, $value ) = $_ =~ /^\s*([a-z]{3,8})\s+=\s+"?(.+)"?\s*$/ )
             {
-                unless ( defined( $self->{$current_filesystem}->{$key} ) )
-                {
+                # do not overwrite already known data
+                defined $self->{$current_filesystem}->{$key} and next;
 
-                    # do not overwrite already known data
-                    $self->{$current_filesystem}->{$key} = $value;
-                    if ( ( $key eq 'vfs' ) && defined( $special_fs{$value} ) )
-                    {
-                        $self->{$current_filesystem}->{special} = 1;
-                    }
+                $key eq "dev" and $args{canondev} and -l $value and $value = abs_path($value);
+
+                $self->{$current_filesystem}->{$key} = $value;
+                if ( ( $key eq 'vfs' ) && defined( $special_fs{$value} ) )
+                {
+                    $self->{$current_filesystem}->{special} = 1;
                 }
             }
         }
@@ -350,7 +352,7 @@ Jens Rehsack <rehsack@cpan.org> - L<http://www.rehsack.de/>
 
 Copyright 2004,2005,2006 Nicola Worthington.
 
-Copyright 2008-2013 Jens Rehsack.
+Copyright 2008-2014 Jens Rehsack.
 
 This software is licensed under The Apache Software License, Version 2.0.
 
