@@ -33,28 +33,15 @@ use Params::Util qw(_STRING);
 use Win32::DriveInfo;
 use Carp qw(croak);
 
-$VERSION = '1.405';
+$VERSION = '1.406';
 
 sub version()
 {
     return $VERSION;
 }
 
-my @volInfoAttrs = (
-                     'n/a',
-                     'preserve case',
-                     'case sensitive',
-                     'unicode',
-                     'acl',
-                     'file compression',
-                     'compressed volume'
-                   );
-my @typeExplain = (
-                    'unable to determine', 'no root directory',
-                    'removeable',          'fixed',
-                    'network',             'cdrom',
-                    'ram disk'
-                  );
+my @volInfoAttrs = ( 'n/a', 'preserve case', 'case sensitive', 'unicode', 'acl', 'file compression', 'compressed volume' );
+my @typeExplain = ( 'unable to determine', 'no root directory', 'removeable', 'fixed', 'network', 'cdrom', 'ram disk' );
 
 sub new
 {
@@ -160,7 +147,7 @@ drives are recognized, no UNC names neither file systems mounted to a path.
 
 Copyright 2004,2005,2006 Nicola Worthington.
 
-Copyright 2009,2013 Jens Rehsack.
+Copyright 2009-2014 Jens Rehsack.
 
 This software is licensed under The Apache Software License, Version 2.0.
 
